componenttools.number_is_between_start_and_stop_offsets_of_component_in_seconds
===============================================================================

.. autofunction:: abjad.tools.componenttools.number_is_between_start_and_stop_offsets_of_component_in_seconds.number_is_between_start_and_stop_offsets_of_component_in_seconds
